@@ -1,12 +1,9 @@
 package CGI::Lazy::CookieMonster;
 
 use strict;
-use warnings;
 
 use CGI::Lazy::Globals;
 
-no warnings qw(uninitialized redefine);
-
 #-----------------------------------------------------------------------------------------------------------
 sub getCookie {
 	my $self = shift;
