@@ -1,12 +1,9 @@
 package CGI::Lazy::Image;
 
 use strict;
-use warnings;
 
 use CGI::Lazy::Globals;
 
-no warnings qw(uninitialized redefine);
-
 #-------------------------------------------------------------------------------------------------
 sub dir {
 	my $self = shift;
