@@ -1,13 +1,10 @@
 package CGI::Lazy::Utility;
 
 use strict;
-use warnings;
 
 use CGI::Lazy::Globals;
 use CGI::Lazy::Utility::Debug;
 
-no warnings qw(uninitialized redefine);
-
 #--------------------------------------------------------------
 sub debug {
 	my $self = shift;
